@@ -38,8 +38,8 @@ static char sccsid[] = "@(#)rcmd.c	8.3 (Berkeley) 3/26/94";
 #define __FORCE_GLIBC
 #include <features.h>
 
-#ifdef _LIBC_REENTRANT
-#undef _LIBC_REENTRANT
+#ifdef __UCLIBC_HAS_THREADS__
+#undef __UCLIBC_HAS_THREADS__
 #warning FIXME I am not reentrant yet...
 #endif
 
@@ -81,7 +81,7 @@ int rcmd(ahost, rport, locuser, remuser, cmd, fd2p)
      const char *locuser, *remuser, *cmd;
      int *fd2p;
 {
-#ifdef _LIBC_REENTRANT
+#ifdef __UCLIBC_HAS_THREADS__
 	int herr;
         struct hostent hostbuf;
 	size_t hstbuflen;
@@ -97,7 +97,7 @@ int rcmd(ahost, rport, locuser, remuser, cmd, fd2p)
 
 	pid = getpid();
 
-#ifdef _LIBC_REENTRANT
+#ifdef __UCLIBC_HAS_THREADS__
 	hstbuflen = 1024;
 #ifdef __UCLIBC_HAS_MMU__
 	tmphstbuf = alloca (hstbuflen);
@@ -304,14 +304,14 @@ int ruserok(rhost, superuser, ruser, luser)
         struct hostent *hp;
 	u_int32_t addr;
 	char **ap;
-#ifdef _LIBC_REENTRANT
+#ifdef __UCLIBC_HAS_THREADS__
 	size_t buflen;
 	char *buffer;
 	int herr;
 	struct hostent hostbuf;
 #endif
 
-#ifdef _LIBC_REENTRANT
+#ifdef __UCLIBC_HAS_THREADS__
 	buflen = 1024;
 #ifdef __UCLIBC_HAS_MMU__
 	buffer = alloca (buflen);
@@ -437,7 +437,7 @@ iruserok2 (raddr, superuser, ruser, luser, rhost)
 		size_t dirlen;
 		uid_t uid;
 
-#ifdef _LIBC_REENTRANT
+#ifdef __UCLIBC_HAS_THREADS__
 		size_t buflen = sysconf (_SC_GETPW_R_SIZE_MAX);
 		struct passwd pwdbuf;
 #ifdef __UCLIBC_HAS_MMU__
@@ -487,10 +487,7 @@ iruserok2 (raddr, superuser, ruser, luser, rhost)
 }
 
 /* This is the exported version.  */
-int iruserok (raddr, superuser, ruser, luser)
-     u_int32_t raddr;
-     int superuser;
-     const char *ruser, *luser;
+int iruserok (u_int32_t raddr, int superuser, const char * ruser, const char * luser)
 {
 	return iruserok2 (raddr, superuser, ruser, luser, "-");
 }
@@ -508,10 +505,7 @@ int iruserok (raddr, superuser, ruser, luser)
  * Returns 0 if ok, -1 if not ok.
  */
 int
-__ivaliduser(hostf, raddr, luser, ruser)
-	FILE *hostf;
-	u_int32_t raddr;
-	const char *luser, *ruser;
+__ivaliduser(FILE *hostf, u_int32_t raddr, const char *luser, const char *ruser)
 {
 	return __ivaliduser2(hostf, raddr, luser, ruser, "-");
 }
@@ -519,17 +513,14 @@ __ivaliduser(hostf, raddr, luser, ruser)
 
 /* Returns 1 on positive match, 0 on no match, -1 on negative match.  */
 static int
-__icheckhost (raddr, lhost, rhost)
-	u_int32_t raddr;
-	char *lhost;
-	const char *rhost;
+__icheckhost (u_int32_t raddr, char *lhost, const char *rhost)
 {
 	struct hostent *hp;
 	u_int32_t laddr;
 	int negate=1;    /* Multiply return with this to get -1 instead of 1 */
 	char **pp;
 
-#ifdef _LIBC_REENTRANT
+#ifdef __UCLIBC_HAS_THREADS__
 	int save_errno;
 	size_t buflen;
 	char *buffer;
@@ -559,7 +550,7 @@ __icheckhost (raddr, lhost, rhost)
 		return negate * (! (raddr ^ laddr));
 
 	/* Better be a hostname. */
-#ifdef _LIBC_REENTRANT
+#ifdef __UCLIBC_HAS_THREADS__
 	buflen = 1024;
 	buffer = malloc(buflen);
 	save_errno = errno;
@@ -573,7 +564,7 @@ __icheckhost (raddr, lhost, rhost)
 	__set_errno (save_errno);
 #else
 	hp = gethostbyname(lhost);
-#endif /* _LIBC_REENTRANT */
+#endif /* __UCLIBC_HAS_THREADS__ */
 
 	if (hp == NULL)
 		return 0;
@@ -589,8 +580,7 @@ __icheckhost (raddr, lhost, rhost)
 
 /* Returns 1 on positive match, 0 on no match, -1 on negative match.  */
 static int
-__icheckuser (luser, ruser)
-	const char *luser, *ruser;
+__icheckuser (const char *luser, const char *ruser)
 {
 
     /*
@@ -623,8 +613,7 @@ __icheckuser (luser, ruser)
  * Returns 1 for blank lines (or only comment lines) and 0 otherwise
  */
 static int
-__isempty(p)
-	char *p;
+__isempty(char *p)
 {
     while (*p && isspace (*p)) {
 	++p;
